@@ -39,6 +39,7 @@ type WorldConfig = {
 };
 export class WorldModel {
   config: WorldConfig;
+  ui_id: string;
   rows: number;
   cols: number;
   vwalls: any;
@@ -78,6 +79,7 @@ export class WorldModel {
 
   init(
     config: WorldConfig,
+    ui_id: string,
     rows: number,
     cols: number,
     vwalls = [],
@@ -108,7 +110,7 @@ export class WorldModel {
     this.vwalls = vwalls;
     this.hwalls = hwalls;
     this.config = config;
-
+    this.ui_id = ui_id;
     let screen_height = $(window).height() || DEFAULT_HEIGHT;
     let grid_height = Math.max(screen_height * 0.6, MIN_HEIGHT);
 
@@ -131,7 +133,28 @@ export class WorldModel {
     this.messages = messages;
     this.flags = flags;
 
-    this.draw_canvas();
+    return this.init_with_id(this.ui_id);
+  }
+
+  init_with_id(ui_id: string) {
+    //clean up
+    let elem = $(`#${this.ui_id}`);
+    let old_grid = $('.konva-grid .content').not(elem);
+
+    if (!!old_grid) {
+      old_grid.remove();
+    }
+    if (elem.length === 0) {
+      return $('.konva-grid')
+        .append($('<div>', { id: this.ui_id, class: ' .content' }))
+        .promise()
+        .then((elem) => {
+          console.log('drawing full canvas');
+          return this.draw_canvas();
+        });
+    }
+    console.log(`#${this.ui_id} already exists returning`);
+    return elem.promise();
   }
 
   skeleton() {
@@ -167,48 +190,58 @@ export class WorldModel {
   }
 
   init_ui() {
-    let wrapper = document.createElement('div');
-    wrapper.setAttribute('class', 'ttgt-wrapper');
-    wrapper.innerHTML = this.skeleton().trim();
+    $('.ttgt-wrapper').remove();
+    let wrapper = $('<div>', { class: 'ttgt-wrapper' }).append(
+      this.skeleton().trim()
+    );
     $(function () {
       $('.ttgt-sidebar-bttn').on('click', function () {
         $('#container').toggle();
       });
     });
-    this.wrapper = wrapper;
+    this.wrapper = wrapper[0] as HTMLDivElement;
   }
 
   draw_canvas() {
-    let stage = new Konva.Stage({
-      container: 'konva-grid',
-      width: this.width + NUMBER_PADDING,
-      height: this.height + NUMBER_PADDING,
-    });
+    try {
+      let stage = new Konva.Stage({
+        container: this.ui_id,
+        width: this.width + NUMBER_PADDING,
+        height: this.height + NUMBER_PADDING,
+      });
 
-    this.ui = {
-      stage: stage,
-      layers: {
-        bg: new Konva.Layer(),
-        main: new Konva.Layer({ offsetX: -1 * NUMBER_PADDING }),
-        line: new Konva.Layer(),
-      },
-    };
+      this.ui = {
+        stage: stage,
+        layers: {
+          bg: new Konva.Layer(),
+          main: new Konva.Layer({ offsetX: -1 * NUMBER_PADDING }),
+          line: new Konva.Layer(),
+        },
+      };
 
-    this.robots[0].init_canvas();
-    this.robots[0].draw();
+      this.robots[0].init_canvas();
+      this.robots[0].draw();
 
-    stage.add(this.ui.layers.bg);
-    stage.add(this.ui.layers.main);
-    stage.add(this.ui.layers.line);
+      stage.add(this.ui.layers.bg);
+      stage.add(this.ui.layers.main);
+      stage.add(this.ui.layers.line);
 
-    this.draw_border();
-    this.draw_grid();
-    this.draw_objects();
-    this.draw_stats();
-    this.draw_envelops();
-    this.draw_flags();
-    this.draw_drop_goals(this.drop_goals);
-    this.ui.layers.main.draw();
+      this.draw_border();
+      this.draw_grid();
+      this.draw_objects();
+      this.draw_stats();
+      this.draw_envelops();
+      this.draw_flags();
+      this.draw_drop_goals(this.drop_goals);
+      return this.ui.layers.main.draw();
+    } catch (error) {
+      console.log(
+        '🚀 ~ file: world_model.ts ~ line 238 ~ WorldModel ~ draw_canvas ~ error',
+        error
+      );
+
+      return Promise.reject(error);
+    }
   }
 
   draw_stats() {
