@@ -12,9 +12,12 @@ import { MODULE_NAME, MODULE_VERSION } from './version';
 // Import the CSS
 import '../css/widget.css';
 import { WorldModel } from './models/world_model';
+import $ from 'jquery';
 
 import PQueue from 'p-queue';
 const queue = new PQueue({ concurrency: 1 });
+//Allowed method without valid maze
+const ALLOWED_METHOD = ['halt', 'draw_all'];
 
 export class MazeModel extends DOMWidgetModel {
   defaults() {
@@ -53,10 +56,19 @@ export class MazeView extends DOMWidgetView {
       params: any;
       cb: any;
       stats?: any;
+      ui_id: string;
     } = JSON.parse(this.model.get('current_call'));
 
-    this.report_stats(current_call.stats);
+    console.log(
+      `#${current_call.ui_id} need to call current_method: ${current_call.method_name}`
+    );
 
+    if (!current_call.method_name) {
+      console.log('clearing queue');
+      queue.clear();
+    }
+
+    this.report_stats(current_call.stats);
     if (current_call.method_name === 'halt') {
       return this.halt();
     } else {
@@ -71,6 +83,19 @@ export class MazeView extends DOMWidgetView {
                 )
               : null;
 
+          if (
+            !ALLOWED_METHOD.some((e) => e === current_call.method_name) &&
+            !$(`#${current_call.ui_id}`).length
+          ) {
+            console.log(
+              'maze is not loaded or invalid id: ',
+              current_call.ui_id,
+              current_call.method_name,
+              current_call.method_name in ALLOWED_METHOD
+            );
+            return resolve(null);
+          }
+
           console.log('current_call in promise -> new code', current_call);
           let that = this;
           Promise.resolve(ret)
@@ -87,7 +112,15 @@ export class MazeView extends DOMWidgetView {
               that.model.save_changes();
               return data;
             })
-            .then(resolve);
+            .then(resolve)
+            .catch((err) => {
+              console.log(
+                'error =>',
+                current_call.method_name,
+                'execution failed',
+                err
+              );
+            });
         });
       });
     }
@@ -95,6 +128,7 @@ export class MazeView extends DOMWidgetView {
 
   draw_all = (
     world_config: any,
+    ui_id: string,
     rows: number,
     cols: number,
     vwalls: [],
@@ -110,6 +144,7 @@ export class MazeView extends DOMWidgetView {
   ) => {
     return this.world_model.init(
       world_config,
+      ui_id,
       rows,
       cols,
       vwalls,
@@ -126,11 +161,12 @@ export class MazeView extends DOMWidgetView {
   };
 
   halt = () => {
+    console.log('halting and clearing queue');
     return queue.clear();
   };
 
   move_to = (index: number, x: number, y: number) => {
-    return this.world_model.robots[index]?.move_to(x, y);
+    return this.world_model && this.world_model.robots[index]?.move_to(x, y);
   };
 
   report_stats = (stats: any) => {
